ResourceStatus enum

Status of a resource that is provided to the UI.

Inheritance
Available extensions

Values

LOADING → const ResourceStatus
TRANSIENT → const ResourceStatus
SUCCESS → const ResourceStatus
ERROR → const ResourceStatus

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isError bool

Available on ResourceStatus, provided by the ResourceUtils extension

no setter
isLoading bool

Available on ResourceStatus, provided by the ResourceUtils extension

no setter
isSuccess bool

Available on ResourceStatus, provided by the ResourceUtils extension

no setter
isTransient bool

Available on ResourceStatus, provided by the ResourceUtils extension

no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ResourceStatus>
A constant List of the values in this enum, in order of their declaration.